/*
 * @Description: 流程页面
 * @version:
 * @Author: jooey wong
 * @Date: 2020-07-14 15:00:45
 * @LastEditors: jooey wong
 * @LastEditTime: 2020-07-15 10:31:28
 */
import request from '@/utils/request'

/**
 * @author: jooey wong
 * @description: 查询审批历史记录
 * @param {String} instanceId 实例流程Id，只有在点击提交之后才会生成
 */
export const queryWfTaskMess = instanceId => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wftaskmess/queryWfTaskMesss`,
    method: 'get',
    params: {
      instanceId: instanceId
    }
  })
}

/**
 * @author: jooey wong
 * @description: 获取第一节点模板
 * @param processId
 */
export const getFirstTemplate = processId => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wftemplate/getFirstTemplate`,
    method: 'get',
    params: {
      processId
    }
  })
}

/**
 * @author WangXinYu
 * @Describe 提交节点 提交功能
 * @param {String} processId 流程id
 * @param {String} queryProcessCommitDtoList 传递的值
 * @param {String} commitMessage 提交 驳回 通过
 * @param {String} takeuserMes 指定审批人的信息
 * @return
 **/
export const onProcessSubmit = (
  processId,
  queryProcessCommitDtoList,
  commitMessage,
  takeuserMes
) => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wfprocessfield/addAndStartProcessInstance`,
    method: 'post',
    data: {
      processId,
      queryProcessCommitDtoList,
      commitMessage,
      takeuserMes
    }
  })
}

/**
 * @author: WangXinYu
 * @describe: 审批节点 通过驳回
 * @param: {String} instanceId 实例id
 * @param: {String} userTaskId 任务id
 * @param: {String} queryProcessCommitDtoList 模板表单数据
 * @param: {String} commitMessage 提交 驳回 通过
 * @return:
 **/
export const completeTask = (
  processId,
  instanceId,
  userTaskId,
  queryProcessCommitDtoList,
  commitMessage,
  takeUserMes
) => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wfinstance/complateTask`,
    method: 'post',
    data: {
      processId,
      instanceId,
      userTaskId,
      queryProcessCommitDtoList,
      commitMessage,
      takeUserMes
    }
  })
}

/**
 * @author WangXinYu
 * @describe 控制流程中通过和驳回的 按钮显示
 * @param {String} taskId
 * @param {String} processId
 **/
export const getCommitBtns = (taskId, processId) => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wfprocess/commitButton/${taskId}`,
    method: 'get',
    params: {
      processId,
      taskId
    }
  })
}

/**
 * @author WangXinYu
 * @describe 获取指定审批人功能
 * @param {String} processId 流程ID
 * @param {String} taskId 任务ID 提交是的时候没有任务ID 就传个 ‘’
 **/
export const getRolesByInsId = (processId, taskId = '') => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wfprocess/getRolesByinsId`,
    method: 'get',
    params: {
      processId,
      taskId
    }
  })
}

/**
 * @author WangXinYu
 * @describe 提交人 撤销功能
 * @param {String} instanceId 实例id
 * @param {String} taskId 任务id
 * @param {String} remarks 备注
 **/
export const revokeProcess = (instanceId, taskId, remarks) => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wfprocess/repalce`,
    method: 'post',
    data: {
      instanceId,
      taskId,
      remarks
    }
  })
}

/**
 * @author WangXinYu
 * @describe 审批人 拒绝操作
 * @param {string} instanceId 实例Id
 * @param {string} taskId 任务Id
 * @param {string} remarks 意见
 **/
export const rejectProcess = (instanceId, taskId, remarks) => {
  return request({
    baseURL: process.env.VUE_APP_WORKFLOW,
    url: `wfprocess/return`,
    method: 'post',
    data: {
      instanceId,
      taskId,
      remarks
    }
  })
}
/**
 * @Description:  /inuser/detail
 * @author wanghaiying
 * @date 2020/8/7
 */
export const queryInJurors = params => {
  return request({
    baseURL: process.env.VUE_APP_INTERNAL,
    url: '/injuror/queryInJurors',
    method: 'get',
    params
  })
}
/**
 * @author WangXinYu
 * @describe 员工加班费管理 -- 根据年月（yyyyMM） 查询加班信息
 * @param {Object} param : month(yyyyMM)
 **/
export const queryOverTimeWorks = param => {
  return request({
    baseURL: process.env.VUE_APP_INTERNAL,
    url: '/inovertimework/queryInOvertimeWorks/' + param.month,
    method: 'get'
  })
}
/**
 * @author WangXinYu
 * @describe 工加班费管理 -- 更新补助信息
 * @param { Array } inOvertimeWork
 **/
export const updateOvertimePaySubsidy = inOvertimeWork => {
  return request({
    baseURL: process.env.VUE_APP_INTERNAL,
    url: '/inovertimework/update',
    method: 'put',
    data: {
      inOvertimeWorkStr: JSON.stringify(inOvertimeWork)
    }
  })
}
/**
 * @Description:  /inuser/detail
 * @author wanghaiying
 * @date 2020/8/7
 */
export const queryInJurorApplys = userId => {
  return request({
    baseURL: process.env.VUE_APP_INTERNAL,
    url: '/injurorapply/queryInJurorApplys',
    method: 'get',
    params: userId
  })
}
